﻿using System;

namespace XUIML.Data
{
	/// <summary> Describes a XUIML node with a boolean value. </summary>
	public class Boolean : Node
	{
		#region Private Fields

		/// <summary> The default value. </summary>
		private bool DefaultValue;

		/// <summary> The internal boolean value. </summary>
		private bool InternalValue;
		
		#endregion

		#region Public Properties

		/// <summary> The boolean value. </summary>
		public bool Value { get { return InternalValue; } set { InternalValue = value; RequestUpdate(); } }

		/// <summary> Gets a value indicating whether the current value is default or not. </summary>
		public bool IsDefault { get { return DefaultValue == InternalValue; } }

		#endregion
			
		#region Public Constructors

		/// <summary> Initializes a new instance of the <see cref="XUIML.Boolean"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Boolean (string name, Node parent = null) : this(name, parent, false) {}

		/// <summary> Initializes a new instance of the <see cref="XUIML.Boolean"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		/// <param name="value"> The default value. </param>
		public Boolean (string name, Node parent, bool value) : base(name, parent)
		{ DefaultValue = InternalValue = value; }
		
		#endregion

		#region Public Methods

		public static implicit operator bool(Boolean boolean) { return boolean.Value; }

		public override void FromString (string value) { Value = bool.Parse(value); }

		public override string ToString () { return this.Value.ToString(); }

		#endregion
	}
}
