using System;

namespace XUIML.Data
{
	/// <summary> Describes a XUIML node with a numerical index value. </summary>
	public class Index : Node
	{
		#region Private Fields

		/// <summary> The default value. </summary>
		private int DefaultValue;

		/// <summary> The internal index value. </summary>
		private int InternalValue;
		
		#endregion

		#region Public Properties
		
		/// <summary> The numerical index value. </summary>
		public int Value { get { return InternalValue; } set { InternalValue = value; RequestUpdate(); } }

		/// <summary> Gets a value indicating whether the current value is default or not. </summary>
		public bool IsDefault { get { return DefaultValue == InternalValue; } }

		#endregion
		
		#region Public Constructor

		/// <summary> Initializes a new instance of the <see cref="XUIML.Index"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Index (string name, Node parent = null) : this(name, parent, 0) {}

		/// <summary> Initializes a new instance of the <see cref="XUIML.Index"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		/// <param name="value"> The default value. </param>
		public Index (string name, Node parent, int value) : base(name, parent)
		{ DefaultValue = InternalValue = value; }
		
		#endregion
		
		#region Public Methods
		
		public static implicit operator int (Index index) { return index.Value; }

		public void Update(Index index) { this.Value = index.Value; }

		public void Update(int index) { this.Value = index; }

		public override void FromString (string value) { Value = int.Parse(value); }

		public override string ToString () { return this.Value.ToString(); }

		#endregion

	}
}

