﻿using System;

namespace XUIML.Data
{
	/// <summary> Describes a XUIML node with a numerical value. </summary>
	public class Number : Node
	{
		#region Private Fields

		/// <summary> The default value. </summary>
		private float DefaultValue;

		/// <summary> The internal numerical value. </summary>
		private float InternalValue;
		
		#endregion

		#region Public Properties

		/// <summary> The numerical value. </summary>
		public float Value { get { return InternalValue; } set { InternalValue = value; RequestUpdate(); } }

		/// <summary> Gets a value indicating whether the current value is default or not. </summary>
		public bool IsDefault { get { return DefaultValue == InternalValue; } }

		#endregion

		#region Public Constructors

		/// <summary> Initializes a new instance of the <see cref="XUIML.Number"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Number (string name, Node parent = null) : this(name, parent, 0.0f) {}

		/// <summary> Initializes a new instance of the <see cref="XUIML.Number"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		/// <param name="value"> The default value. </param>
		public Number (string name, Node parent, float value) : base(name, parent)
		{ DefaultValue = InternalValue = value; }

		#endregion

		#region Public Methods

		public static implicit operator float(Number number) { return number.Value; }

		public static implicit operator Number(float number) { return new Number("number", null, number); }

		public void Update(float number) { this.Value = number; }

		public void Update(Number number) { this.Value = number.Value; }

		public override void FromString (string value) { Value = float.Parse(value); }

		public override string ToString () { return this.Value.ToString(); }

		#endregion
	}
}
