﻿using System;

namespace XUIML.Data
{
	/// <summary> Describes a XUIML node with a text value. </summary>
	public class Text : Node
	{
		#region Private Fields

		/// <summary> The default value. </summary>
		private string DefaultValue;

		/// <summary> The internal text value. </summary>
		private string InternalValue;

		#endregion

		#region Public Properties

		/// <summary> The text value. </summary>
		public string Value { get { return InternalValue; } set { InternalValue = value; RequestUpdate(); } }

		/// <summary> Gets a value indicating whether this instance is empty. </summary>
		/// <value><c>true</c> if this instance is empty; otherwise, <c>false</c>.</value>
		public bool IsEmpty { get { return (InternalValue == null || InternalValue.Length == 0); } }

		/// <summary> Gets a value indicating whether the current value is default or not. </summary>
		public bool IsDefault { get { return DefaultValue == InternalValue; } }

		#endregion
			
		#region Public Constructor

		/// <summary> Initializes a new instance of the <see cref="XUIML.Text"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Text (string name, Node parent) : this(name, parent, "")
		{ InternalValue = DefaultValue = "";}

		/// <summary> Initializes a new instance of the <see cref="XUIML.Text"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		/// <param name="value"> The default value. </param>
		public Text (string name, Node parent, string value) : base(name, parent)
		{ InternalValue = DefaultValue = value; }
		
		#endregion

		#region Public Methods
		
		public static implicit operator string(Text text) { return text.Value; }

		public static implicit operator Text(string text) { return new Text("", null, text); }

		public void Update(Text text) { this.Value = text.Value; }

		public void Update(string text) { this.Value = text; }

		public override void FromString (string value) { Value = value; }

		public override string ToString () { return Value; }

		#endregion
	}
}
