using UnityEngine;
using System;

namespace XUIML.Data
{
	/// <summary> Describes a Date XUIML Node. </summary>
	public sealed class Date : Node
	{
		#region Public Properties
		
		/// <summary> The day number. </summary>
		public Index Day { get; private set; }
		
		/// <summary> The month number. </summary>
		public Index Month { get; private set; }
		
		/// <summary> The year number. </summary>
		public Index Year { get; private set; }

		#endregion
		
		#region Public Constructors
		
		/// <summary> Initializes a new instance of the <see cref="XUIML.Color"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Date (string name, Node parent = null) : base(name, parent)
		{
			this.Day = new Index("day", this);
			this.Month = new Index("month", this);
			this.Year = new Index("year", this);
		}
		
		/// <summary> Initializes a new instance of the <see cref="XUIML.Data.Color"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		/// <param name="day"> The day number. </param>
		/// <param name="month"> The month number. </param>
		/// <param name="year"> The year number. </param>
		public Date (string name, Node parent, Index day, Index month, Index year) : this(name, parent)
		{ this.Day = day; this.Month = month; this.Year = year; }
		
		#endregion
		
		#region Public Methods
		
		/// <summary> Updates the node with specific values. </summary>
		///  <param name="color"> the color values. </param>
		public void Update(Date date)
		{ Day.Value = date.Day; this.Month.Value = date.Month; this.Year.Value = date.Year; }
		
		/// <summary> Updates the node with specific values. </summary>
		/// <param name="day"> The day number. </param>
		/// <param name="month"> The month number. </param>
		/// <param name="year"> The year number. </param>
		public void Update(Index day, Index month, Index year)
		{ Day.Value = day; this.Month.Value = month; this.Year.Value = year; }
		
		/// <summary> Updates the node with specific values. </summary>
		/// <param name="day"> The day number. </param>
		/// <param name="month"> The month number. </param>
		/// <param name="year"> The year number. </param>
		public void Update(int day, int month, int year)
		{ Day.Value = day; this.Month.Value = month; this.Year.Value = year; }
		
		/// <summary> Obtains the object data from a string representation. </summary>
		/// <param name="value"> The string with the object data.</param>
		public override void FromString (string value)
		{ Serialization.CSV.Deserialize(this, value); }
		
		/// <summary> Returns a string that represents the current object. </summary>
		/// <returns>A string that represents the current object.</returns>
		public override string ToString ()
		{ return string.Format ("[{0}, {1}, {2}]", this.Day, this.Month, this.Year); }
		
		#endregion
	}
}

