﻿using System;
using XUIML.Data;

namespace XUIML.Model
{
	/// <summary> Represents the root node of a complete XUIML dataset. </summary>
	public sealed class Root: Node
	{
		#region Public Properties
		
		/// <summary> The End User data. </summary>
		public NodeSet<User> Users { get; private set; }
		
		/// <summary> The physical environment information. </summary>
		public NodeSet<Environment> Environments { get; private set; }
		
		/// <summary> The platform data. </summary>
		public NodeSet<Platform> Platforms { get; private set; }

		/// <summary> Returns the root node instance.</summary>
		public static Root Instance { get; private set;}

		#endregion
		
		#region Public Constructor
		
		/// <summary> Initializes a new instance of the <see cref="XUIML.Platform"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Root () : base("xuiml", null)
		{
			// Make sure only one root node is allowed
			if(Instance == null) Instance = this; else throw new Exception ("Only one root node is allowed!");

			// Initialize the child nodes
			this.Users = new NodeSet<User>("user", this);
			this.Environments = new NodeSet<Environment>("environment", this);
			this.Platforms = new NodeSet<Platform>("platform", this);
		}
		
		#endregion
	}
}