﻿using System;
using XUIML.Data;

namespace XUIML.Model
{
	/// <summary> Contains the personal information of the end user. </summary>
	public class Persona : Node
	{
		#region Public Properties

		/// <summary> The real name of the user. </summary>
		public Text RealName { get; private set; }

		/// <summary> The email address of the user. </summary>
		public Text EmailAddress { get; private set; }

		/// <summary> The contact phone of the user. </summary>
		public Text ContactPhone { get; private set; }

		/// <summary> The physical adress of the user. </summary>
		public Text ContactAddress { get; private set; }

		/// <summary> The gender of the user. </summary>
		public Index Gender { get; private set; }

		/// <summary> The birthday date of the user. </summary>
		public Date Birthday { get; private set; }

		/// <summary> The laterality of the user. </summary>
		public Index Laterality { get; private set; }

		/// <summary> The vision capabilities of the user. </summary>
		public Index Vision { get; private set; }

		/// <summary> The vision disabilities of the user. </summary>
		public Index ColorBlindness { get; private set; }

		/// <summary> The interets of the user. </summary>
		public Text Interests { get; private set; }

		#endregion

		#region Public Constructor

		/// <summary> Initializes a new instance of the <see cref="XUIML.Model.Persona"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public Persona(string name, Node parent) : base(name, parent)
		{
			this.RealName = new Text("name",this);
			this.EmailAddress = new Text("email",this);
			this.ContactPhone = new Text("phone",this);
			this.ContactAddress = new Text("address",this);
			this.Gender = new Index("gender",this);
			this.Birthday = new Date("birthday",this);
			this.Laterality = new Index("laterality",this);
			this.Vision = new Index("vision",this);
			this.ColorBlindness = new Index("colorBlindness",this);
			this.Interests = new Text("interests",this);
		}

		#endregion
	}
}