﻿using XUIML.Data;

namespace XUIML.Model
{
	/// <summary> Contains the information of a computer end user.</summary>
	public class User : Node
	{
		#region Public Properties

		/// <summary> The position of the user. </summary>
		public Vector Position { get; private set; }

		/// <summary> The orientation of the user. </summary>
		public Vector Orientation { get; private set; }

		/// <summary> The field of view of the user. </summary>
		public Number FieldOfView { get; private set; }

		/// <summary> The user identities. </summary>
		public NodeSet<Identity> Identities { get; private set; }
		
		/// <summary> The user personas. </summary>
		public NodeSet<Persona> Personas { get; private set; }

		/// <summary> The user preferences. </summary>
		public NodeSet<Preferences> Preferences { get; private set; }

		#endregion
		
		#region Public Constructor

		/// <summary> Initializes a new instance of the <see cref="XUIML.User"/> class. </summary>
		/// <param name="name"> The node name. </param>
		/// <param name="parent"> The parent node. </param>
		public User (string name, Node parent) : base(name, parent)
		{
			this.Position = new Vector("position",this);
			this.Orientation = new Vector("orientation",this);
			this.FieldOfView = new Number("fov",this, 60.0f);
			this.Identities = new NodeSet<Identity>("identity", this);
			this.Personas = new NodeSet<Persona>("persona", this);
			this.Preferences = new NodeSet<Preferences>("preferences", this);
		}

		#endregion
		
	}
}
