using UnityEngine;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	public class CameraImage : MonoBehaviour
	{
		#region Private Fields
		
		/// <summary> The widget behavior. </summary>
		private WidgetBehaviour Widget;

		/// <summary> The camera texture. </summary>
		private static WebCamTexture CameraTexture = null;

		private static int RequestedWidth = 512;

		private static int RequestedHeight = 512;

		#endregion

		#region Public Methods

		/// <summary> The final image obtained by the camera. </summary>
		public static Texture2D FinalImage = null;

		#endregion

		#region Private Methods

		private void Start()
		{
			// Get the parent keyboard reference
			Widget = GetComponentInParent<WidgetBehaviour>();

			Widget.EnabledStateChanged += this.UpdateCameraTexture;
		}

		/// <summary> Called when the user enables the component. </summary>
		private void UpdateCameraTexture(WidgetBehaviour widget)
		{

			if (!AugmentedReality.Initialized || Manager.OnUnityEditor()) return;

			if (Widget.Enabled)
			{
				// Disable AR to allow the access to the front camera
				AugmentedReality.CameraObject.SetActive(false); AugmentedReality.Enabled = false;

				// Create a new texture from the front-facing camera
				if (CameraTexture == null) 
				{
					int frontCameraIndex = 0; int camerasTotal = WebCamTexture.devices.Length;
					for (int cameraIndex = 0; cameraIndex < camerasTotal; cameraIndex++)
						if (WebCamTexture.devices[cameraIndex].isFrontFacing) frontCameraIndex = cameraIndex;
					string cameraName = WebCamTexture.devices[frontCameraIndex].name;
					CameraTexture = new WebCamTexture(cameraName, RequestedWidth, RequestedHeight, 30);
				}

				// Start the camera capture
				CameraTexture.Play();

				// Set the new properties of the texture
				this.renderer.material.SetTexture("_Texture2", CameraTexture);
				this.renderer.material.SetTextureScale("_Texture2", new Vector2(-0.6f,0.9f));
				this.renderer.material.SetTextureOffset("_Texture2",  new Vector2(1f,0f));
			} else {
				// if there is no camera texture, do nothing
				if (CameraTexture == null) return;

				// Save the final image
				int cameraWidth = CameraTexture.width; int cameraHeight = CameraTexture.height;
				int resultWidth = 256; int resultHeight = 256;
				FinalImage = new Texture2D(resultWidth, resultHeight);

				float texelSize = 0;
				if (cameraHeight > resultHeight) texelSize = (float)cameraHeight / (float)resultHeight * 0.9f;
				else texelSize = (float)resultHeight / (float)cameraHeight * 0.9f;

				for(int x = 0; x < resultWidth; x++) 
					for(int y = 0; y < resultHeight; y++) 
						FinalImage.SetPixel(x, y, CameraTexture.GetPixel
							(cameraWidth - (int)(x * texelSize), (int)(y * texelSize)));

				FinalImage.Apply();	

				//Play a Camera shutter sound
				OutputManager.PlaySound("Camera");

				//Debug.LogWarning("Camera Image Obtained");

				// Stop the camera texture
				CameraTexture.Stop();

				// Re-enable AR
				AugmentedReality.CameraObject.SetActive(true); AugmentedReality.Enabled = true;
			}

		}

		#endregion
	}
}