﻿using UnityEngine;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	public class CountdownTimer: MonoBehaviour
	{
		#region Private Fields
		
		/// <summary> The widget behavior. </summary>
		private WidgetBehaviour Widget;
		
		/// <summary> The text node with the remaining time. </summary>
		private Text TimeNode;

		/// <summary> The remaining time. </summary>
		private float RemainingTime;

		#endregion
		
		#region Private Methods
		
		/// <summary> Initialize the instance. </summary>
		private void Start ()
		{
			// Get the widget component
			Widget = GetComponent<WidgetBehaviour>();

			// Get the time textnode
			TimeNode = Widget.TextNodes[0];

			Widget.EnabledStateChanged += this.UpdateRemainingTimeValue;

			// Get the initial time
			UpdateRemainingTimeValue(null);
		}

		/// <summary> Called once per frame. </summary>
		private void Update ()
		{
			// Make sure that the widget is enabled
			if(!Widget.Enabled) return;

			// Check if the countdown has finished and, if so, sends the widget an activation request
			if(((int)RemainingTime) <= 0) { Widget.React("activate"); return; }

			// Update the time value and the node (which, in turn, will update the TextMesh of the widget)
			RemainingTime -= Time.deltaTime;
			TimeNode.Update(((int)RemainingTime).ToString());
		}

		/// <summary> Updates the remaining time value. </summary>
		/// <param name="widget"> The widget behavior. </param>
		private void UpdateRemainingTimeValue(WidgetBehaviour widget)
		{ if (Widget.Enabled) RemainingTime = float.Parse(TimeNode.Value); }

		#endregion
	}
}