﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Enables the input of user metrics. </summary>
	public class ValueSelector : Keyboard
	{
		#region Private Fields
		
		/// <summary> The material displayed when a key is selected. </summary>
		private UnityEngine.Material SelectedMaterial;
		
		/// <summary> The material displayed when a key is unselected. </summary>
		private UnityEngine.Material UnselectedMaterial;
		
		/// <summary> The selected key. </summary>
		private Key SelectedKey = null;
		
		#endregion
		
		#region Private Methods
		
		/// <summary> Initializes the keyboard. </summary>
		private void Start()
		{
			// Initialize the basic elements
			Initialize();
			
			// Get the current widget behaviour
			WidgetBehaviour widget = this.GetComponent<WidgetBehaviour>();
			
			// Get the text node associated to this keyboard
			TextNode = Manager.GetResource(widget.WidgetNode, "Value");
			
			SelectedMaterial = Resources.Load<UnityEngine.Material>("Themes/Futuristic/Materials/KeySelected");
			UnselectedMaterial = Resources.Load<UnityEngine.Material>("Themes/Futuristic/Materials/KeyUnselected");
			
			UpdateKeyMaterials();
		}
		
		/// <summary> Updates the key materials. </summary>
		private void UpdateKeyMaterials()
		{
			foreach (Key key in Keys) key.renderer.material = UnselectedMaterial;
			
			if (SelectedKey != null) SelectedKey.renderer.material = SelectedMaterial;
			
			Element.UpdateMaterials(gameObject);
		}
		
		
		#endregion
		
		#region Public Methods
		
		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Set the key as the selected one
			SelectedKey = key;

			// Use the last letter of the key name as the value
			TextNode.Update(key.name.Substring(key.name.Length -1));
			
			if (key.animation != null & key.animation.GetClip("HideKey") != null)
				Manager.Invoke(key.animation.GetClip("HideKey").length, UpdateKeyMaterials);
		}
		
		#endregion
	}
}

