﻿using UnityEngine;
using System.Collections;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> A base class for manipulation management. </summary>
	public class Manipulator: MonoBehaviour
	{
		#region Public Enumerations

		/// <summary> The different manipulation operations. </summary>
		public enum ManipulationOperation { None, Translate, Rotate, Scale };

		/// <summary> The axes affected by the manipulation operations. </summary>
		public enum Axes { X, Y , Z, XY, YZ, XZ, XYZ };

		#endregion

		#region Protected Fields

		/// <summary> The widget node. </summary>
		protected Widget WidgetNode;

		/// <summary> The widget behaviour. </summary>
		protected WidgetBehaviour Widget;

		/// <summary> The widget element. </summary>
		protected GameObject WidgetObject;

		#endregion

		#region Protected Methods

		/// <summary> Initialize the basic manipulator properties. </summary>
		protected void Initialize()
		{
			// Get the parent widget
			Widget = transform.parent.GetComponent<WidgetBehaviour>();
			WidgetObject = Widget.gameObject;
			WidgetNode = Widget.WidgetNode;
		}

		#endregion
		
		#region Public Methods

		/// <summary> Activates the manipulator. </summary>
		public virtual void Activate() {}

		/// <summary> Deactivates the manipulator. </summary>
		public virtual void Deactivate() {}

		/// <summary> Updates the manipulation operation. </summary>
		/// <param name="component">The associated manipulator component.</param>
		public virtual void UpdateManipulationOperation(ManipulatorComponent component, RaycastHit hit) {}

		#endregion
	}
}