using UnityEngine;
using System;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Handles a manipulator component. </summary>
	public class ManipulatorComponent : InputManager.PrimaryTarget
	{
		#region Public Fields

		public Manipulator.ManipulationOperation ManipulationOperation;

		public Manipulator.Axes Axes;

		public Manipulator ParentManipulator;

		#endregion

		#region Private Methods

		public void Start()
		{
			if (ParentManipulator == null) ParentManipulator = GetComponentInParent<PivotPointManipulator>();
			if (ParentManipulator != null && !ParentManipulator.enabled) ParentManipulator = null;
		}

		public void Update()
		{
			bool isVisible = (transform.lossyScale.magnitude != 0);
			if (renderer != null && renderer.enabled != isVisible)
			{
				renderer.enabled = isVisible;
				if (collider != null) collider.enabled = isVisible;
			}
		}


		public void OnPressed (RaycastHit hit)
		{ if (ParentManipulator != null) ParentManipulator.UpdateManipulationOperation(this, hit); }

		public void OnCrossed(RaycastHit hit)
		{ if (ParentManipulator != null) ParentManipulator.UpdateManipulationOperation(this, hit); }

		public void OnReleased (RaycastHit hit)
		{ if (ParentManipulator != null) ParentManipulator.UpdateManipulationOperation(this, hit); }

		public void OnReleasedWithoutPressing (RaycastHit hit)
		{ if (ParentManipulator != null) ParentManipulator.UpdateManipulationOperation(this, hit); }

		#endregion
	}
}