using UnityEngine;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Creates an explosion effect. </summary>
	public class Explosion : MonoBehaviour
	{
		#region Private Fields
		
		/// <summary> The total size of the explosion. </summary>
		private float Size;

		/// <summary> The current life time. </summary>
		private float CurrentLife;

		/// <summary> The total life time. </summary>
		private float TotalLife;

		/// <summary> The global explosion number. </summary>
		private static int Number = 0;

		private static float Albedo = 0.25f;
		#endregion
		
		#region Private Methods

		/// <summary> Called once per frame. </summary>
		private void Update ()
		{
			CurrentLife += Time.deltaTime;

			if (CurrentLife >= TotalLife) { GameObject.DestroyImmediate(gameObject); return; }

			float timeScale; float albedoLife = TotalLife * Albedo;
			if (CurrentLife <= albedoLife) timeScale = CurrentLife / albedoLife;
			else timeScale = 1.0f -((CurrentLife - albedoLife) / (TotalLife - albedoLife));

			this.transform.localScale = Vector3.one * timeScale * Size;

			this.renderer.material.mainTextureOffset = new Vector2(0.0f, -CurrentLife);
		}

		#endregion
		
		#region Public Methods

		public static void Create(Transform parent, Vector3 position, float size, float life, UnityEngine.Color color)
		{
			GameObject explosionObject = GameObject.CreatePrimitive(PrimitiveType.Sphere);
			explosionObject.name = "Explosion" + Explosion.Number++;
			explosionObject.renderer.material = Resources.Load<UnityEngine.Material>("Themes/Futuristic/Materials/Explosion");
			explosionObject.transform.parent = parent;
			explosionObject.transform.localPosition = position;
			explosionObject.transform.localScale = Vector3.zero;
			explosionObject.layer = parent.gameObject.layer;
			explosionObject.renderer.material.color = color;
			Explosion explosion = explosionObject.AddComponent<Explosion>();
			explosion.Size = size; 
			explosion.TotalLife = life;
			explosion.CurrentLife = 0;
		}

		#endregion
	}
}