﻿using UnityEngine;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Defines a widget that generates other widgets on certain conditions. </summary>
	public class Generator : MonoBehaviour
	{
		#region Private Fields
		
		/// <summary> The widget behavior. </summary>
		private WidgetBehaviour Widget;

		/// <summary> The widget behavior. </summary>
		private Widget WidgetNode;

		private int Seed = 0;

		private string ItemName = null;

		private float Frequency = 1.0f;

		private int LastItemGenerationIndex = 1;

		private float LastItemGenerationTime;

		private List<Widget> Items;

		#endregion
		
		#region Private Methods

		/// <summary> Initialize the instance. </summary>
		private void Start ()
		{
			// Get the parent widget and its node
			Widget = GetComponent<WidgetBehaviour>();
			WidgetNode = Widget.WidgetNode;

			// Initialize the list of items
			Items = new List<Widget>();

			// Use the initialize action to fill the required generation parameters
			Behavior.Action initilizeAction = WidgetNode.Behavior.Actions["initialize"];
			if (initilizeAction != null)
			{
				foreach(Behavior.Action.Reaction reaction in initilizeAction.Reactions)
				{
					if (reaction.Key == "GeneratorSeed") Seed = int.Parse(reaction.Value);
					else if (reaction.Key == "GeneratorItem") ItemName = reaction.Value;
				}
			}

			// Initialize the random number generator
			Random.seed = Seed;
		}

		// Update is called once per frame
		void Update ()
		{
			// Make sure that the widget is enabled
			if(!Widget.Enabled || transform.lossyScale == Vector3.zero) return;

			LastItemGenerationTime += Time.deltaTime;
			if (LastItemGenerationTime > Frequency)
			{
				Widget item = new Widget(ItemName + (LastItemGenerationIndex++), WidgetNode.Widgets);
				item.Type.Update(ItemName);
				float angle = Random.value * 2.0f * Mathf.PI;
				float range = 0.3f;
				item.Position.X.Update(Mathf.Sin(angle) * range);
				item.Position.Z.Update(Mathf.Cos(angle) * range);
				Items.Add(item);

				LastItemGenerationTime = 0f;
			}
		}


		#endregion
	}
}
