﻿using UnityEngine;
using System.Collections;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Defines the behaviour of a slelection target. </summary>
	public class Spaceship : MonoBehaviour
	{
		#region Private Fields

		/// <summary> The widget behavior. </summary>
		private WidgetBehaviour Widget;

		/// <summary> The shield gameobject. </summary>
		private GameObject Shield;

		/// <summary> The spaceship gameobject. </summary>
		private GameObject Ship;

		/// <summary> The current selection operation node. </summary>
		private Text CurrentSelectionOperation;

		/// <summary> The smoke particle system. </summary>
		private ParticleSystem Smoke;

		/// <summary> The ship acceleration. </summary>
		private float ShipAcceleration = 0.0f;

		/// <summary> The ship acceleration increment. </summary>
		private float ShipAccelerationIncrement = 0.002f;

		/// <summary> The ship maximum acceleration. </summary>
		private float ShipMaxAcceleration = 0.2f;

		#endregion


		#region Private Methods
		// Use this for initialization
		void Start ()
		{
			// Get the widget behaviour
			Widget = GetComponentInParent<WidgetBehaviour>();

			// Get the current selection operation node
			CurrentSelectionOperation = Manager.GetResource(null, "CurrentOperation");

			// Get the important child objects
			foreach(Transform child in this.transform)
			{
				if (child.name == "Shield") Shield = child.gameObject;
				if (child.name == "Spaceship") Ship = child.gameObject;
			}

			Smoke = GetComponentInChildren<ParticleSystem>();
			SetSmokeActive(false);
		}

		// Update is called once per frame
		void Update ()
		{
			if (!Widget.Enabled) { /*if (Smoke.renderer.enabled) SetSmokeActive(true);*/ return; }

			// Update the time metrics
			float deltaTime = Time.deltaTime;
			switch (CurrentSelectionOperation.Value)
			{
			case "SelectionSimple": MetricsManager.AddTime(MetricsManager.TaskId.UC3A, deltaTime); break;
			case "SelectionMultiple": MetricsManager.AddTime(MetricsManager.TaskId.UC3B, deltaTime); break;
			case "SelectionArea": MetricsManager.AddTime(MetricsManager.TaskId.UC3C, deltaTime); break;
			}

			// If the conditions are right, launch the rocket
			if (Ship.transform.position == Vector3.zero && Manager.GetResource(null, "UseCase3Countdown").Value == "0")
			{ 
				// Start the ship engines
				Shield.collider.enabled = false;
				ShipAcceleration = 0.001f;
				Smoke.gameObject.SetActive(true);
				Smoke.enableEmission = true; 
			
				// Play the sound
				OutputManager.PlaySound("SelectionWin", transform.position);
			}

			if (ShipAcceleration > 0f)
			{
				Ship.transform.position += new Vector3 (0, Time.deltaTime * ShipAcceleration, 0);
				if (ShipAcceleration < ShipMaxAcceleration) ShipAcceleration += ShipAccelerationIncrement;

				float shieldSize = 1 - (Ship.transform.position.y * 10f);
				if (shieldSize < 0) shieldSize = 0;
				Shield.transform.localScale = new Vector3(1, shieldSize, 1);
			}
		}

		void SetSmokeActive(bool state) 
		{ Smoke.enableEmission = Smoke.renderer.enabled = state; Smoke.gameObject.SetActive(state); }

		#endregion
	}
}
