using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Alphabetic keyboard. </summary>
	public class KeyboardAlphabetic : Keyboard
	{
		#region Private Methods

		/// <summary> Initializes the keyboard. </summary>
		private void Start() { Initialize(); }

		/// <summary> Called after the frame drawing. </summary>
		private void LateUpdate()
		{	if (ParentWidget.Selected) MetricsManager.AddTime(MetricsManager.TaskId.UC1A, Time.deltaTime); }

		#endregion
		
		#region Public Methods

		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Check the given value
			if (key.Values == null || key.Values[key.CurrentIndex] == null) return;

			// Get the text value
			string textValue = TextNode.Value;
			string keyValue = key.Values[key.CurrentIndex];
			int index = key.CurrentIndex;

			// Analyze the given value
			switch (keyValue)
			{
			case "OK": ParentWidget.Selected = false; break;
			case "<--":
				// Check if there is a character to remove
				if (textValue.Length > 0)
				{
					// Get the last character
					char lastChar = textValue[textValue.Length - 1];
					
					// If the previous char belongs to a different key index, update the entire keyboard
					if (char.IsUpper(lastChar) && key.CurrentIndex != 0) foreach(Key k in Keys) k.ChangeIndex(0);
					else if (char.IsLower(lastChar) && key.CurrentIndex != 1) foreach(Key k in Keys) k.ChangeIndex(1);
					
					// Remove the last character
					textValue = textValue.Remove(textValue.Length - 1);
					
				}

				// Increase the error metric
				MetricsManager.AddError(MetricsManager.TaskId.UC1A);

				break;
			case "ABC": foreach(Key currentKey in Keys) currentKey.ChangeIndex(0); break;
			case "abc": foreach(Key currentKey in Keys) currentKey.ChangeIndex(1); break;
			case "SYM": foreach(Key currentKey in Keys) currentKey.ChangeIndex(2); break;
			case "Sym": foreach(Key currentKey in Keys) currentKey.ChangeIndex(3); break;
			default:
				// Add the text value to the text
				textValue += keyValue;

				// If a blanck space is inserted, return to uppercase
				if (index == 1 && keyValue == " ") { foreach(Key currentKey in Keys) currentKey.ChangeIndex(0); break; }

				// If a uppercase letter is inserted, go to lowercase
				if (index == 0) { foreach(Key currentKey in Keys) currentKey.ChangeIndex(1); break; }
				break;
			}

			// Update the text node
			TextNode.Update(textValue);
		}

		#endregion
	}
}

