﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Color picker keyboard. </summary>
	public class KeyboardColor : Keyboard
	{
		#region Private Fields

		/// <summary> The different colors available. </summary>
		private XUIML.Data.Color[] Colors;

		/// <summary> The color names. </summary>
		private string[] ColorNames;

		#endregion
		
		#region Private Methods
		
		/// <summary> Initializes the keyboard. </summary>
		private void Start()
		{
			// Initialize the basic elements
			Initialize();

			// Create the color palette
			Colors = new XUIML.Data.Color[8];
			Colors[0] = new XUIML.Data.Color("Red", null, 0.8f, 0.0f, 0.0f);
			Colors[1] = new XUIML.Data.Color("Orange", null, 0.8f, 0.4f, 0.0f); // Orange
			Colors[2] = new XUIML.Data.Color("Yellow", null, 0.8f, 0.8f, 0.0f); // Yellow
			Colors[3] = new XUIML.Data.Color("Green", null, 0.0f, 0.8f, 0.0f); // Green
			Colors[4] = new XUIML.Data.Color("Aqua", null, 0.0f, 0.8f, 0.8f); // Aqua
			Colors[5] = new XUIML.Data.Color("Blue", null, 0.0f, 0.0f, 0.9f); // Blue
			Colors[6] = new XUIML.Data.Color("Violet", null, 0.8f, 0.0f, 0.8f); // Violet
			Colors[7] = new XUIML.Data.Color("Grey", null, 0.8f, 0.8f, 0.8f); // Grey

			// Temporal
			UpdateColors(null);

			// Set the text values
			Texts["Instructions"].text = Manager.GetResource(ParentWidgetNode, "Instructions");
			ColorNames = Manager.GetResource(ParentWidgetNode, "Values").Value.Split(new string[]{","}, 
				System.StringSplitOptions.RemoveEmptyEntries);

			// Update the colors whenever the parent widget is selected
			ParentWidget.SelectedStateChanged += UpdateColors;
		
			// Detect when the parent widget is selected
			ParentWidget.SelectedStateChanged += this.OnWidgetSelected;
		}
		
		
		/// <summary> Detects when the keyboard is loaded. </summary>
		private void OnWidgetSelected (WidgetBehaviour widget)
		{ if (widget.Selected && !TextNode.IsEmpty) MetricsManager.AddError(MetricsManager.TaskId.UC1C); }


		/// <summary>/ Updates the colors that are visible. </summary>
		private void UpdateColors(WidgetBehaviour widget)
		{
			foreach (Key key in Keys)
			{
				// Set the key color
				if (key.name.Contains("Color"))
					key.renderer.material.color = Element.ToColor(Colors[int.Parse(key.name.Replace("Key_Color",""))]);
			}
		}

		/// <summary> Called after the frame drawing. </summary>
		private void LateUpdate()
		{	if (ParentWidget.Selected) MetricsManager.AddTime(MetricsManager.TaskId.UC1C, Time.deltaTime); }

		#endregion
		
		#region Public Methods
		
		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Analyze the given key name
			switch (key.name)
			{
			case "Key_OK": ParentWidget.Selected = false; return;
			default:

				// Get the current color index
				int colorNumber = int.Parse(key.name.Replace("Key_Color",""));

				// Update the text
				TextNode.Update (ColorNames[colorNumber]);

				// Update the User.Preferences.MainColor node
				Root.Instance.Users[0].Preferences[0].MainColor.Update(Colors[colorNumber]);

				// Update the scene materials
				Unity.Element.UpdateMaterials();

				// Update the color keys
				UpdateColors(null);

				break;
			}
		}


		#endregion
	}
}

