﻿using UnityEngine;
using System.Collections;
using System.Globalization;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Date Picker keyboard. </summary>
	public class KeyboardDate : Keyboard
	{
		#region Private Fields
		
		private System.DateTime Date;

		private CultureInfo Culture;

		#endregion
		
		#region Private Methods
		
		/// <summary> Initializes the keyboard. </summary>
		private void Start()
		{
			// Initialize the basic elements
			Initialize();

			// Set the initial date
			Culture = new CultureInfo("en-us");
			Date = new System.DateTime(1984, 1, 1);

			// Initialize the text meshes
			Texts["DayValue"].text = Date.ToString("dd", Culture);
			Texts["MonthValue"].text = Date.ToString("MMMM", Culture);
			Texts["YearValue"].text = Date.ToString("yyyy", Culture);
		
			// Detect when the parent widget is selected
			ParentWidget.SelectedStateChanged += this.OnWidgetSelected;
		}
		
		
		/// <summary> Detects when the keyboard is loaded. </summary>
		private void OnWidgetSelected (WidgetBehaviour widget)
		{ if (widget.Selected && !TextNode.IsEmpty) MetricsManager.AddError(MetricsManager.TaskId.UC1B); }


		/// <summary> Called after the frame drawing. </summary>
		private void LateUpdate()
		{	if (ParentWidget.Selected) MetricsManager.AddTime(MetricsManager.TaskId.UC1B, Time.deltaTime); }

		#endregion
		
		#region Public Methods
		
		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Check the given value
			if (key.Values == null || key.Values[key.CurrentIndex] == null) return;

			// Store the current date
			System.DateTime oldDate = Date;

			// Analyze the given key name
			switch (key.name)
			{
			case "Key_01": ParentWidget.Selected = false; break;
			case "Key_11": Date = Date.AddDays(-1); if (Date.Month != oldDate.Month) Date = Date.AddMonths(+1); break;
			case "Key_12": Date = Date.AddDays(+1); if (Date.Month != oldDate.Month) Date = Date.AddMonths(-1); break;
			case "Key_21": Date = Date.AddMonths(-1); if (Date.Year != oldDate.Year) Date = Date.AddYears(+1); break;
			case "Key_22": Date = Date.AddMonths(+1); if (Date.Year != oldDate.Year) Date = Date.AddYears(-1);break;
			case "Key_31": Date = Date.AddYears(-1); break;
			case "Key_32": Date = Date.AddYears(+1); break;
			}

			Texts["DayValue"].text = Date.ToString("dd", Culture);
			Texts["MonthValue"].text = Date.ToString("MMMM", Culture);
			Texts["YearValue"].text = Date.ToString("yyyy", Culture);

			// Update the text node
			TextNode.Update(Date.Date.ToString("dd-MM-yyyy", Culture));

			// FIX: Store the values in the persona node
			Root.Instance.Users[0].Personas[0].Birthday.Update(Date.Day, Date.Month, Date.Year);

			// FIX: Store the current Age in the UserAge node
			System.DateTime zeroTime = new System.DateTime(1, 1, 1); System.TimeSpan span = System.DateTime.Now - Date;
			Manager.GetResource(null, "UserAge").Update((((int)(zeroTime + span).Year - 1)).ToString());
		}
		
		#endregion
	}
}

