using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Email address keyboard. </summary>
	public class KeyboardEmailAddress : Keyboard
	{
		#region Private Methods
		
		/// <summary> Initializes the keyboard. </summary>
		private void Start() { Initialize(); }

		/// <summary> Called after the frame drawing. </summary>
		private void LateUpdate()
		{	if (ParentWidget.Selected) MetricsManager.AddTime(MetricsManager.TaskId.UC1A, Time.deltaTime); }

		#endregion
		
		#region Public Methods
		
		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Check the given value
			if (key.Values == null || key.Values[key.CurrentIndex] == null) return;
			
			// Get the text value
			string textValue = TextNode.Value;
			string keyValue = key.Values[key.CurrentIndex];

			// Analyze the given value
			switch (keyValue)
			{
			case "OK": ParentWidget.Selected = false; break;
			case "<--":
				// Check if there is a character to remove
				if (textValue.Length > 0)
				{
					// Remove the last character
					textValue = textValue.Remove(textValue.Length - 1);
				}
				
				// Increase the error metric
				MetricsManager.AddError(MetricsManager.TaskId.UC1A);
				
				break;
			case "abc": foreach(Key currentKey in Keys) currentKey.ChangeIndex(0); break;
			case "ABC": foreach(Key currentKey in Keys) currentKey.ChangeIndex(1); break;
			case "!#$": foreach(Key currentKey in Keys) currentKey.ChangeIndex(2); break;
			default:

				// Add the text value to the text
				textValue += keyValue;

				break;
			}
			
			// Update the text node
			TextNode.Update(textValue);
		}
		
		#endregion
	}
}

