﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using XUIML.Data;
using XUIML.Model;

namespace XUIML.Unity
{
	/// <summary> Photobooth keyboard. </summary>
	public class KeyboardPhoto : Keyboard
	{
		#region Private Methods
		
		/// <summary> Initializes the keyboard. </summary>
		private void Start()
		{
			// Initialize the basic elements
			Initialize();

			// Display the instructions message
			Texts["Instructions"].text = Manager.GetResource(ParentWidgetNode, "Instructions").Value.Replace("//", "\n");

			// Make sure that the photo is properly updated
			ParentWidget.SelectedStateChanged += UpdatePhoto;
			
			// Detect when the parent widget is selected
			ParentWidget.SelectedStateChanged += this.OnWidgetSelected;
		}
		
		
		/// <summary> Detects when the keyboard is loaded. </summary>
		private void OnWidgetSelected (WidgetBehaviour widget)
		{ if (widget.Selected && !TextNode.IsEmpty) MetricsManager.AddError(MetricsManager.TaskId.UC1C); }

		/// <summary> Updates the photo image. </summary>
		private void UpdatePhoto(WidgetBehaviour widget)
		{
			if(CameraImage.FinalImage != null)
			{
				GameObject photoButton = GameObject.Find("PhotoButton");
				photoButton.renderer.material.SetTexture("_Texture2", CameraImage.FinalImage);
				photoButton.renderer.material.SetTextureScale("_Texture2", new Vector2(0.9f,1.0f));
				photoButton.renderer.material.SetTextureOffset("_Texture2",  new Vector2(0f,0f));
			}
		}

		/// <summary> Called after the frame drawing. </summary>
		private void LateUpdate()
		{	if (ParentWidget.Selected) MetricsManager.AddTime(MetricsManager.TaskId.UC1C, Time.deltaTime); }

		#endregion
		
		#region Public Methods
		
		/// <summary> Called upon key pressing. </summary>
		/// <param name="key"> The pressed Key. </param>
		public override void KeyPressed(Key key)
		{
			// Analyze the given key name
			switch (key.name)
			{
			case "Key_OK": ParentWidget.Selected = false; return;
			case "PhotoButton":
				TextNode.Update(Manager.GetResource(ParentWidgetNode, "Obtained").Value);
				Manager.GetResource(null,"PhotoModeActive").Update("True");
				return;
			}

		}
		
		#endregion
	}
}

